Learn R Programming

AquaEnv (version 1.0-5)

K_HNO3: dissociation constants of HNO3, HNO2, H2SO4, HS

Description

PUBLIC function: dissociation constants that are taken invariant

Usage

K_HNO3(...)
K_HNO2(...)
K_H2SO4(...)
K_HS(...)

Value

the dissociation constant of HNO3, HNO2, H2SO4 and HS in mol/kg-solution on the free proton pH scale.

These dissociation constants are taken as a constant, i.e. they do not vary with temperature nor with salinity.

Arguments

...

not used, included for consistency with other dissociation constantss

Author

Karline Soetaert (Karline.Soetaert@nioz.nl).

References

K_HNO2: mol/l, NBS pH scale, hybrid constant (Riordan2005)

K_HNO3: assumed on mol/kg-soln and free pH scale, stoichiometric constant

K_H2SO4: assumed on mol/kg-soln and free pH scale, stoichiometric constant (Atkins1996)

K_HS: assumed on mol/kg-soln and free pH scale, stoichiometric constant (Atkins1996)

Examples

Run this code
K_H2SO4(35, 15)
K_H2SO4()

Run the code above in your browser using DataLab