Description
PRIVATE function: adds an element to an object of class aquaenv
Usage
# S3 method for aquaenv
c(aquaenv, x, ...)
Value
object of class aquaenv with the added element
Arguments
- aquaenv
object of class aquaenv
- x
a vector of the form c(value, name) representing the element to be inserted into the object of class aquaenv
- ...
further arguments will be passed
Author
Andreas F. Hofmann. Maintained by Karline Soetaert (Karline.Soetaert@nioz.nl).