Learn R Programming

AquaEnv (version 1.0-4)

length.aquaenv: length.aquaenv

Description

PRIVATE function: returns the (maximal) length of the elements in an object of class aquaenv (i.e. > 1 if one of the input variables was a vector)

Usage

# S3 method for aquaenv
length(x, ...)

Value

the maximal length of the elements in the object of class aquaenv

Arguments

x

object of class aquaenv

...

further arguments will be passed

Author

Andreas F. Hofmann. Maintained by Karline Soetaert (Karline.Soetaert@nioz.nl).