Learn R Programming

AquaEnv (version 1.0-4)

merge.aquaenv: merge.aquaenv

Description

PRIVATE function: merges the elements of two objects of class aquaenv: element names are taken from the first argument, the elements of which are also first in the merged object

Usage

# S3 method for aquaenv
merge(x, y, ...)

Value

object of class aquaenv with merged elements

Arguments

x

object of class aquaenv: this is where the element names are taken from

y

object of class aquaenv: must contain at leas all the element (names) as aquaenv1, extra elements are ignored

...

further arguments will be passed

Author

Andreas F. Hofmann. Maintained by Karline Soetaert (Karline.Soetaert@nioz.nl).